==> zzyj-outputvalcount-impl-3.0.0-20220716.093152-58-sources.jar: com/ejianc/business/outputvalcount/bean/XmjdmxEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目进度明细
 * 
 * @author generator
 * 
 */
 @TableName("vw_xmjdmx")
public class XmjdmxEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="zje")
    private BigDecimal zje; // 总金额
    @TableField(value="stat_date")
    private Date statDate; // 产值统计日期
    @TableField(value="description")
    private String description; // 形象进度描述
    @TableField(value="kgwccz")
    private BigDecimal kgwccz; // 自开工累计完成产值
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="bywccz")
    private BigDecimal bywccz; // 本月完成产值
    @TableField(value="pro_id")
    private Long proId; // 项目
    @TableField(value="tax_mny")
    private BigDecimal taxMny; //
    @TableField(value="production_date")
    private Date productionDate; // 产值时间
    @TableField(value="bnwccz")
    private BigDecimal bnwccz; //


    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }

    public Long getProId() {
        return proId;
    }

    public void setProId(Long proId) {
        this.proId = proId;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }

    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20250828.005358-375-sources.jar: com/ejianc/business/outputvalcount/bean/XmjdmxEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目进度明细
 * 
 * @author generator
 * 
 */
 @TableName("vw_xmjdmx")
public class XmjdmxEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="zje")
    private BigDecimal zje; // 总金额
    @TableField(value="stat_date")
    private Date statDate; // 产值统计日期
    @TableField(value="description")
    private String description; // 形象进度描述
    @TableField(value="kgwccz")
    private BigDecimal kgwccz; // 自开工累计完成产值
    @TableField(value="year")
    private Integer year; // 年份
    @TableField(value="month")
    private Integer month; // 月份
    @TableField(value="bywccz")
    private BigDecimal bywccz; // 本月完成产值
    @TableField(value="pro_id")
    private Long proId; // 项目
    @TableField(value="tax_mny")
    private BigDecimal taxMny; //
    @TableField(value="production_date")
    private Date productionDate; // 产值时间
    @TableField(value="bnwccz")
    private BigDecimal bnwccz; //
    @TableField(value="build_unit_id")
    private Long buildUnitId; // 工程父id
    @TableField(value="bild_unit_name")
    private String bildUnitName; // 施工单位


    public Long getBuildUnitId() {
        return buildUnitId;
    }

    public void setBuildUnitId(Long buildUnitId) {
        this.buildUnitId = buildUnitId;
    }

    public String getBildUnitName() {
        return bildUnitName;
    }

    public void setBildUnitName(String bildUnitName) {
        this.bildUnitName = bildUnitName;
    }

    public BigDecimal getBnwccz() {
        return bnwccz;
    }

    public void setBnwccz(BigDecimal bnwccz) {
        this.bnwccz = bnwccz;
    }

    public Long getProId() {
        return proId;
    }

    public void setProId(Long proId) {
        this.proId = proId;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public Date getProductionDate() {
        return productionDate;
    }

    public void setProductionDate(Date productionDate) {
        this.productionDate = productionDate;
    }

    public BigDecimal getBywccz() {
        return bywccz;
    }

    public void setBywccz(BigDecimal bywccz) {
        this.bywccz = bywccz;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public BigDecimal getZje() {
        return zje;
    }

    public void setZje(BigDecimal zje) {
        this.zje = zje;
    }
    public Date getStatDate() {
        return statDate;
    }

    public void setStatDate(Date statDate) {
        this.statDate = statDate;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public BigDecimal getKgwccz() {
        return kgwccz;
    }

    public void setKgwccz(BigDecimal kgwccz) {
        this.kgwccz = kgwccz;
    }
    public Integer getYear() {
        return year;
    }

    public void setYear(Integer year) {
        this.year = year;
    }
    public Integer getMonth() {
        return month;
    }

    public void setMonth(Integer month) {
        this.month = month;
    }
    
}
